@@ -1,6 +1,6 @@
 #ifndef GCC_TM_H
 #define GCC_TM_H
-#define TARGET_CPU_DEFAULT ((MASK_PA_11|MASK_PA_20|MASK_GAS|MASK_JUMP_IN_DELAY))
+#define TARGET_CPU_DEFAULT ((MASK_PA_11|MASK_PA_20|MASK_GAS))
 #ifndef LIBC_GLIBC
 # define LIBC_GLIBC 1
 #endif
@@ -10,6 +10,9 @@
 #ifndef LIBC_BIONIC
 # define LIBC_BIONIC 3
 #endif
+#ifndef LIBC_MUSL
+# define LIBC_MUSL 4
+#endif
 #ifndef DEFAULT_LIBC
 # define DEFAULT_LIBC LIBC_GLIBC
 #endif
@@ -21,7 +24,6 @@
 # include "insn-constants.h"
 # include "config/pa/pa64-start.h"
 # include "config/pa/pa.h"
-# include "config/dbxelf.h"
 # include "config/elfos.h"
 # include "config/gnu-user.h"
 # include "config/linux.h"
